#
# spec file for package perl-Sereal-Decoder
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Sereal-Decoder
Version:        4.005
Release:        lp152.2.5
%define cpan_name Sereal-Decoder
Summary:        Binary serialization module for Perl (decoder part)
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/Y/YV/YVES/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::ParseXS) >= 2.21
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::Differences)
BuildRequires:  perl(Test::LongString)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Warn)
%{perl_requires}

%description
This library implements a deserializer for an efficient, compact-output,
and feature-rich binary protocol called _Sereal_. Its sister module
Sereal::Encoder implements an encoder for this format. The two are released
separately to allow for independent and safer upgrading.

The Sereal protocol versions that are compatible with this decoder
implementation are currently protocol versions 1, 2, 3 and 4. As it stands,
it will refuse to attempt to decode future versions of the protocol, but if
necessary there is likely going to be an option to decode the parts of the
input that are compatible with version 4 of the protocol. The protocol was
designed to allow for this.

The protocol specification and many other bits of documentation can be
found in the github repository. Right now, the specification is at
https://github.com/Sereal/Sereal/blob/master/sereal_spec.pod, there is a
discussion of the design objectives in
https://github.com/Sereal/Sereal/blob/master/README.pod, and the output of
our benchmarks can be seen at
https://github.com/Sereal/Sereal/wiki/Sereal-Comparison-Graphs.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -name \*.pl -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
# Don't build with smp_flags!
make

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes

%changelog
* Mon Oct 22 2018 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of summary.
* Sun Oct  7 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fixed autogenerated changes
* Wed Feb  7 2018 coolo@suse.com
- updated to 4.005
  see /usr/share/doc/packages/perl-Sereal-Decoder/Changes
* Fri Sep  2 2016 coolo@suse.com
- updated to 3.015
  see /usr/share/doc/packages/perl-Sereal-Decoder/Changes
  3.015 Thu Sep  1 20:18:44 CEST 2016
  * Fix builds under 5.25+
  * Fix various buffer overun bugs found using AFL (thanks to dgryski)
  * Fix issue in decode_from_file()
* Wed Dec  9 2015 coolo@suse.com
- updated to 3.014
  see /usr/share/doc/packages/perl-Sereal-Decoder/Changes
  3.014 Dec  7 2015
  * Fix builds under 5.8.9
  3.012 Dec  6 2015
  * Yet another release related to broken META files.
    ExtUtils::MakeMaker and CPAN::Meta need to be up to date
    or the META files miss stuff.
  3.011 Dec  6 2015
  * No significant changes. Doc typo fixes, and build tweaks.
  3.010 Dec  1 2015
  * Build fixes.
* Wed Dec  2 2015 coolo@suse.com
- updated to 3.009
  see /usr/share/doc/packages/perl-Sereal-Decoder/Changes
  3.009 Nov 30 2015
  * Re-relase 3.008 with updated META files.
  3.008 Nov 27 2015
  * FIX: Win32 build issues.
* Fri Nov 27 2015 coolo@suse.com
- updated to 3.007
  see /usr/share/doc/packages/perl-Sereal-Decoder/Changes
  3.007 Nov 26 2015
  * Build fixes for boxes without any Sereal installed (it seems
    to be common on certain types of smokers, and not on others).
  * [ENCODER]: new sort orders added.
  * Fix incremental parsing of utf8 strings. See
    https://rt.cpan.org/Public/Bug/Display.html?id=93892
  * Encoder fixes.
* Sun Nov 15 2015 coolo@suse.com
- updated to 3.006
  see /usr/share/doc/packages/perl-Sereal-Decoder/Changes
  3.006 Nov 14 2015
  * [DECODER] fix segfaults from heavily corrupted data. Guards
    against various pathological cases which could cause segfaults
    fixed. Thanks to Damian Gryski and "fuzzing sereal with afl"
    for finding these cases.
  * [ENCODER] Various subtle fixes to how we choose whether to serialize
    the string or numeric version of a value, in particular to
    ensure that "00" always round trips as "00", and related issues.
    Note this fix has correctness and performance consequences. In
    some cases values that used to serialized as integers (arguably
    incorrectly) will be serialized as strings instead, and some code
    maybe be slower to serialize.
    NOTE: Some issues related to this subject are not fixable without
    a protocol change. In particular this change may affect the behavior
    of code that uses binary logical operators on values serialized
    with Perl.
    Thanks to Zefram, Tom, and others for help with this issue.
  * Fixups for cast warnings under -Wint-to-ptr builds by using
    using PTR2INT and INT2PTR for casting our objects.
  * Win32 fixes
  * Build improvements
  * Changes to how we generate constants
* Tue Apr 14 2015 coolo@suse.com
- updated to 3.005
  see /usr/share/doc/packages/perl-Sereal-Decoder/Changes
* Sun Jul 13 2014 coolo@suse.com
- initial package 3.001
  * created by cpanspec 1.78.08
